import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import PointsTable from "@/components/sections/user-account/points-table";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { LocaleParams } from "@/types/params";
import { HydrationBoundary, dehydrate } from "@tanstack/react-query";


async function PointsPage({ params }: { params: LocaleParams }) {
	const { locale } = await params;

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/user-account",
			label: {
				en: "User Account",
				ar: "حساب المستخدم",
			},
		},
		{
			href: "/user-account/points",
			label: {
				en: "Points",
				ar: "نقاط",
			},
		},
	];

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
	]);

	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<main className="block overflow-hidden text-gray-700">
				<Header />
				<PageBreadcrump
					backgroundUrl={"/heros/points.jpg"}
					locale={locale}
					subtitle={{
						en: "Bin Taleb Company",
						ar: "شركة بن طالب",
					}}
					title={{
						en: "User Account",
						ar: "حساب المستخدم",
					}}
					breadcrumbItems={breadcrumbItems}
				/>

				<div>
					<div className="relative mx-auto w-full max-w-10xl px-4 sm:px-4 md:px-16 lg:px-24">
						<PointsTable language={locale} />
					</div>
				</div>

				<Footer />
			</main>
		</HydrationBoundary>
	);
}

export default PointsPage;
